@@ -23,10 +23,11 @@ def StartLogfile(interval):
     else: data.logfolder=data.defaultlogfolder
     
     print "Logfolder:",  data.logfolder
-    try:
-        os.mkdir(data.logfolder)
-    except:
-        print "Failed to create logfolder!"
+    if(not os.path.exists(data.logfolder)): #create log folder
+        try:
+            os.mkdir(data.logfolder)
+        except:
+            print "Failed to create logfolder!"
         
     
     #open file, write header
@@ -43,7 +44,7 @@ def StartLogfile(interval):
             ", value_smoothing: " + str(data.sample_smoothing )+"\n"
     data.logfile.write(data.Header)
     data.logfile.write("Note: \n")
-    data.Note=""
+#    data.Note=""
 
 
 
@@ -174,12 +175,13 @@ def OpenLogFile():
 #  Load log file  to change Note (on line 2)
 ###########################################################################
 def ChangeNoteInFile():    
+    print "Reopen log file and add note:",  data.Note
     file = open(data.logfolder+data.logfilename, 'w')
     print "Open logfile",  data.logfilename,  ", change Note to\"",  data.Note,  "\" in file",  data.logfilename
-   
-   
+
     file.write(data.Header)
     file.write("Note: "+data.Note+"\n")
+    i=0
     for i in range(0,  data.arrDataIndex):
         d=str(data.arrData[0][i]) + ", " + str(data.arrData[1][i]) + ", " +  str(data.arrData[2][i])
         file.write(d+"\n")
@@ -210,11 +212,12 @@ def LoadConfig():
         data.Yscale = config.getint('main', 'Yscale')
         data.user = config.get('main', 'user')
         data.lastlogfile = config.get('main', 'lastlogfile')
-        print "Configuration loaded ("+data.ConfigFile+")"
         data.OfflineMode = config.get('main', 'OfflineMode')
+        data.DelayStartTime = config.getint('main', 'DelayStartTime')
+        print "Configuration loaded ("+data.ConfigFile+")"
 #    else:
     except: #use default config
-        print data.configfolder+data.ConfigFile + " not existing, using default parameters..."
+        print data.configfolder+data.ConfigFile + " not existing or not read properly, using default parameters..."
         try:
             config.add_section('main')
         except:
@@ -230,6 +233,7 @@ def LoadConfig():
         config.set('main', 'user', str(data.user))      
         config.set('main', 'lastlogfile', str(data.lastlogfile))    
         config.set('main', 'OfflineMode', str(data.OfflineMode))      
+        config.set('main', 'DelayStartTime', str(data.DelayStartTime))    
 
     
     #print usefull data
@@ -249,7 +253,9 @@ def LoadConfig():
 ###########################################################################
 # Write the configuration into the config file
 ###########################################################################
-def WriteConfig(config):
+def WriteConfig(config):    
+        config.set('main', 'trigger', str(data.trigger))  
+        
         f=data.configfolder+data.ConfigFile
         print "Save configuration ("+f+")"
         if (not os.path.exists(data.configfolder)):
